Struct Subscription
pub struct Subscription {
pub(crate) filter: TopicFilterBuf,
pub(crate) options: SubscriptionOptions,
}Expand description
A single topic filter with its associated subscription options.
Build one with Subscription::new and pass it to
MqttClient::subscribe or
SubscribeBuilder::and.
Example
use finmqtt_core::wire::QoS;
use finmqtt_tokio::Subscription;
let sub = Subscription::new("sensors/#".parse().unwrap(), QoS::AtLeastOnce);
let sub = Subscription::new("sensors/#".parse().unwrap(), QoS::AtLeastOnce).no_local(true);Fields
filter: TopicFilterBufoptions: SubscriptionOptionsImplementations
impl Subscription
impl Subscription
pub const fn new(filter: TopicFilterBuf, qos: QoS) -> Self
pub const fn new(filter: TopicFilterBuf, qos: QoS) -> Self
Creates a new subscription for filter at the given qos.
pub const fn no_local(self, no_local: bool) -> Self
pub const fn no_local(self, no_local: bool) -> Self
When true, the broker will not forward messages published by this
client back to the same client on this subscription.
pub const fn retain_as_published(self, rap: bool) -> Self
pub const fn retain_as_published(self, rap: bool) -> Self
Sets the Retain As Published option (v5).
pub const fn retain_handling(self, rh: RetainHandling) -> Self
pub const fn retain_handling(self, rh: RetainHandling) -> Self
Sets the Retain Handling option (v5).