Struct UnsubscribeBuilder
pub struct UnsubscribeBuilder {
cmd_tx: Sender<Command>,
filters: Vec<TopicFilterBuf>,
}Expand description
Builder for unsubscribing from one or more topic filters.
Obtained via MqttClient::unsubscribe.
Call send to get an UnsubscribeFuture that can be
awaited for UNSUBACK, or converted to a QueuedUnsubscribeFuture via
UnsubscribeFuture::queued.
Fields
cmd_tx: Sender<Command>filters: Vec<TopicFilterBuf>Implementations
impl UnsubscribeBuilder
impl UnsubscribeBuilder
pub(crate) fn new(cmd_tx: Sender<Command>, filter: TopicFilterBuf) -> Self
pub fn and(self, filter: TopicFilterBuf) -> Self
pub fn and(self, filter: TopicFilterBuf) -> Self
Adds an additional filter to this unsubscribe batch.
pub fn send(self) -> UnsubscribeFuture ⓘ
pub fn send(self) -> UnsubscribeFuture ⓘ
Returns an UnsubscribeFuture that drives the UNSUBSCRIBE to
completion.
No work is done until the future is first polled. Await the future to
wait for UNSUBACK, or call UnsubscribeFuture::queued to convert it
into a QueuedUnsubscribeFuture that resolves as soon as the
unsubscribe is recorded locally.